==> fileCenter-2.1.18-sources.jar: com/gtis/fileCenter/web/FileCenterController.java <==
package com.gtis.fileCenter.web;

import com.alibaba.fastjson.JSON;
import com.gtis.config.AppConfig;
import com.gtis.fileCenter.model.Node;
import com.gtis.fileCenter.model.Space;
import com.gtis.fileCenter.service.FileService;
import com.gtis.fileCenter.service.FileStoreService;
import com.gtis.fileCenter.service.NodeService;

import com.gtis.generic.util.JsonUtils;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.collections.MapUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import java.io.File;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * Created by jane on 14-2-27.
 * 文件中心服务
 */
@RequestMapping("/fc.do")
public class FileCenterController extends BaseController {
    public static final String ACCESS_CONTROL_ALLOW_ORIGN = "Access-Control-Allow-Origin";

	/** 文件中心的表空间 */
    public static final String WORK_FLOW_STUFF = "WORK_FLOW_STUFF";

    @RequestMapping(method = RequestMethod.GET)
    public ModelAndView fc(HttpServletResponse response, Model model, String proid, String readOnly, String type, HttpServletRequest request){
        response.setHeader(ACCESS_CONTROL_ALLOW_ORIGN,"*");
        //获得工作流附件工作流空间节点Id
        Space space = nodeService.getWorkSpace(WORK_FLOW_STUFF,true);
        Node prjNode = nodeService.getNode(space.getId(), proid,true);
        Integer rootId = prjNode.getId();
        //获得工作流文件中心节点访问令牌
        String token = nodeService.getToken(prjNode);
        Map params = new HashMap();
        params.put("disable",false);
        params.put("rootId",rootId.toString());
        params.put("token",token);
        params.put("readOnly",readOnly);
        model.addAttribute("rootId",rootId.toString());
        model.addAttribute("token",token);
        model.addAttribute("readOnly",readOnly);
        request.setAttribute("params", JsonUtils.toString(params));
        return new ModelAndView("fc");
    }
}

==> fileCenter-2.2.1-sources.jar: com/gtis/fileCenter/web/FileCenterController.java <==
package com.gtis.fileCenter.web;

import com.alibaba.fastjson.JSON;
import com.gtis.config.AppConfig;
import com.gtis.fileCenter.model.Node;
import com.gtis.fileCenter.model.Space;
import com.gtis.fileCenter.service.FileService;
import com.gtis.fileCenter.service.FileStoreService;
import com.gtis.fileCenter.service.NodeService;

import com.gtis.generic.util.JsonUtils;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.collections.MapUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import java.io.File;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * Created by jane on 14-2-27.
 * 文件中心服务
 */
@RequestMapping("/fc")
public class FileCenterController extends BaseController {
    public static final String ACCESS_CONTROL_ALLOW_ORIGN = "Access-Control-Allow-Origin";

	/** 文件中心的表空间 */
    public static final String WORK_FLOW_STUFF = "WORK_FLOW_STUFF";

    @RequestMapping(value = "",method = RequestMethod.GET)
    public ModelAndView fc(HttpServletResponse response, Model model, String proid, String readOnly, String type, HttpServletRequest request){
        response.setHeader(ACCESS_CONTROL_ALLOW_ORIGN,"*");
        //获得工作流附件工作流空间节点Id
        Space space = nodeService.getWorkSpace(WORK_FLOW_STUFF,true);
        Node prjNode = nodeService.getNode(space.getId(), proid,true);
        Integer rootId = prjNode.getId();
        //获得工作流文件中心节点访问令牌
        String token = nodeService.getToken(prjNode);
        Map params = new HashMap();
        params.put("disable",false);
        params.put("rootId",rootId.toString());
        params.put("token",token);
        params.put("readOnly",readOnly);
        model.addAttribute("rootId",rootId.toString());
        model.addAttribute("token",token);
        model.addAttribute("readOnly",readOnly);
        request.setAttribute("params", JsonUtils.toString(params));
        return new ModelAndView("fc");
    }

    @RequestMapping(value = "/folder.do",method = RequestMethod.GET)
    public ModelAndView folder(HttpServletResponse response, Model model, String proid, String readOnly, String type, HttpServletRequest request){
        response.setHeader(ACCESS_CONTROL_ALLOW_ORIGN,"*");
        //获得工作流附件工作流空间节点Id
        Space space = nodeService.getWorkSpace(WORK_FLOW_STUFF,true);
        Node prjNode = nodeService.getNode(space.getId(), proid,true);
        Integer rootId = prjNode.getId();
        //获得工作流文件中心节点访问令牌
        String token = nodeService.getToken(prjNode);

        boolean isroot = true;
        String folderName=request.getParameter("folderName");
        try {
            if (StringUtils.isNotBlank(folderName)){
                folderName = java.net.URLDecoder.decode(folderName,"utf-8");
            }
            if (prjNode != null && StringUtils.isNotBlank(folderName)){
                Node childNode = nodeService.getChildNode(prjNode.getId(),folderName);
                if (childNode != null){
                    isroot = false;
                    rootId = childNode.getId();
                    //获得工作流文件中心节点访问令牌
                    token = nodeService.getToken(childNode);
                }
            }
        }catch (Exception ex){
            ex.printStackTrace();
        }

        Map params = new HashMap();
        params.put("rootId",rootId.toString());
        params.put("token",token);
        params.put("disable",false);
        params.put("readOnly",readOnly);
        model.addAllAttributes(params);
        request.setAttribute("params", JsonUtils.toString(params));
        if (isroot){
            return new ModelAndView("fc");
        }else{
            return new ModelAndView("folder");
        }
    }
}
